import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Enumeration;
import java.util.Vector;

/**
 * Ein Klasse zum Lesen, ndern und Speichern einer Konfigurationsdatei.
 *
 * @author  <a href="mailto:jochen@kupperschmidt.de">Jochen Kupperschmidt</a>
 * @version 05. November 2002
 */
public class SimpleConfigParser
{
	private String filename;
	public  Vector config;

	/* Neues Objekt instanziiern und Existenz der Datei prfen */
	public SimpleConfigParser(String filename) throws IOException {
		if (filename == null) {
			throw new IOException("Es wurde keine Datei angegeben!");
		}
		this.filename = filename;
		File file = new File(filename);
		if (!file.exists()) {
			throw new IOException("Die angegebene Datei existiert nicht!");
		}
		loadConfig();
	}

	/* Konfigurationsdaten aus Datei lesen */
	public void loadConfig() throws IOException {
		String line;
		config = new Vector();
		BufferedReader in = new BufferedReader(new FileReader(filename));
		while ((line = in.readLine()) != null) {
			config.addElement(getKeyValuePair(line));
		}
		in.close();
	}

	/* Konfigurationsdaten in Datei speichern */
	public void saveConfig() throws IOException {
		BufferedWriter out = new BufferedWriter(new FileWriter(filename));
		for (Enumeration elem = config.elements(); elem.hasMoreElements(); ) {
			KeyValuePair pair = (KeyValuePair) elem.nextElement();
			if (pair != null) {
				out.write(pair.getKey() + " = " + pair.getValue());
				out.newLine();
			}
		}
		out.close();
	}

	/* Konfigurationsdaten im Speicher bearbeiten */
	public void editConfig(int index, String newKey, Object newValue) throws IOException {
		KeyValuePair pair = (KeyValuePair) config.elementAt(index);
		if (newKey.length() > 0) {
			pair.setKey(newKey);
		}
		if (newValue.toString().length() > 0) {
			pair.setValue(newValue);
		}
		config.setElementAt(pair, index);
	}

	/* Schlssel-Wert-String auseinanderschneiden */
	public KeyValuePair getKeyValuePair(String pairString) throws IOException {
		// bei JDK Version <1.4 alternativ StringTokenizer oder
		// String.indexOf() und String.substring() verwenden
		String[] pairArray = pairString.split("=");
		try {
			return new KeyValuePair(pairArray[0].trim(), (Object) pairArray[1].trim());
		} catch (ArrayIndexOutOfBoundsException e) {
			throw new IOException("Das Name-Wert-Paar ist nicht vollstndig!");
		}
	}
}

