import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;
import java.util.Enumeration;
import java.util.Vector;

/**
 * Ein bonsolenbasiertes Interface zum SimpleConfigParser.
 *
 * @author  <a href="mailto:jochen@kupperschmidt.de">Jochen Kupperschmidt</a>
 * @version 05. November 2002
 */
public class TextUI
{
	public String				filename;
	public SimpleConfigParser	scp;
	public StringBuffer			strbuf;

	/* Einsprungspunkt */
	public static void main(String[] args) {
		if (args.length != 1) {
			System.out.println("Usage: java TextUI <filename>");
			System.exit(1);
		}
		TextUI textui = new TextUI(args[0]);
	}

	/* Erzeugt eine neue Instanz des TextUI */
	public TextUI(String filename) {
		this.filename = filename;
		try {
			scp = new SimpleConfigParser(filename);
			while (true) {
				showMenu();
			}
		} catch (IOException e) {
			System.out.println(e.getMessage());
		}
	}

	/* Zeigt den Auswahldialog fr mgliche Aktionen an */
	public void showMenu() throws IOException {
		strbuf = new StringBuffer();
		strbuf.append("\n--- SimpleConfigParser -- TextUI --------------\n\n");
		strbuf.append("Geladene Datei: " + filename + "\n\n");
		strbuf.append("  1 - Konfigurationsdaten anzeigen\n");
		strbuf.append("  2 - Konfigurationsdaten bearbeiten\n");
		strbuf.append("  3 - Konfigurationsdaten speichern\n");
		strbuf.append("  0 - Programm verlassen\n");
		System.out.println(strbuf.toString());

		boolean isChoosable = false;
		int choice;
		while (!isChoosable) {
			choice = readInt("Aktion: ");
			isChoosable = true;
			switch (choice) {
				case 0: quitProgram(); pause(); break;
				case 1: showConfig();  pause(); break;
				case 2: editConfig();  pause(); break;
				case 3: saveConfig();  pause(); break;
				default: isChoosable = false;
			}
		}
	}

	/* Kleiner Dank und Info am Ende */
	public void quitProgram() {
		strbuf = new StringBuffer();
		strbuf.append("\n--- SimpleConfigParser ------------------------\n\n");
		strbuf.append("Danke, dass Sie dieses Programm benutzt haben!\n");
		strbuf.append("   Copyright (c) 2002 Jochen Kupperschmidt\n");
		strbuf.append("\n-----------------------------------------------\n");
		System.out.print(strbuf);
		System.exit(0);
	}

	/* Zeigt die aktuell im Speicher befindlichen Konfigurationsdaten an */
	public void showConfig() throws IOException {
		strbuf = new StringBuffer();
		strbuf.append("\n--- Konfigurationsdaten -----------------------\n\n");
		int idx = 0;
		for (Enumeration elem = scp.config.elements(); elem.hasMoreElements(); ) {
			idx++;
			KeyValuePair pair = (KeyValuePair) elem.nextElement();
			if (pair != null) {
				strbuf.append("#" + idx + ":\t" + pair.getKey() + "\t  =   ");
				strbuf.append(pair.getValue() + "\t [" + pair.getType() + "]\n");
			}
		}
		System.out.println(strbuf.toString());
	}

	/* Erfragt vom Benutzer Werte und bergibt diese an die entsprechende SCP-Methode */
	public void editConfig() throws IOException {
		showConfig();

		int index = readInt("Zu bearbeitende Zeile: ");
		index--;
		try {
			KeyValuePair pair = (KeyValuePair) scp.config.elementAt(index);
			System.out.println("\nNur <Enter>, um den bisherigen Wert beizubehalten.");
			String newKey   = readString("Neuen Schluessel eingeben [" + pair.getKey() + "]: ");
			String newValue = readString("Neuen Wert       eingeben [" + pair.getValue() + "]: ");
			System.out.println();
			scp.editConfig(index, newKey, newValue);
		} catch (ArrayIndexOutOfBoundsException ignored) {
			editConfig();
		}
	}

	/* Veranlasst die Speicherung der aktuellen Konfigurationsdaten */
	public void saveConfig() throws IOException {
		System.out.print("\n--- Konfigurationsdaten speichern -------------\n\n");
		scp.saveConfig();
	}

	/* Wartet auf ein <Enter> vom Benutzer */
	public static void pause() throws IOException {
		BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
		System.out.print("<Enter>");
		String unpause = input.readLine();
	}

	/* Verlangt vom Benutzer die Eingabe eines Strings */
	public static String readString(String prompt) throws IOException {
		BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
		System.out.print(prompt);
		return input.readLine();
	}

	/* Verlangt vom Benutzer die Eingabe eines int-Werts */
	public static int readInt(String prompt) throws IOException {
		boolean isInt = false;
		BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
		while (!isInt) {
			try {
				System.out.print(prompt);
				int intValue = (new Integer(input.readLine())).intValue();
				return intValue;
			} catch (NumberFormatException ignored) {}
		}
		return 0;
	}
}